@@ -23,15 +23,15 @@ from osducli.config import CONFIG_CRS_CATALOG_URL
 @click.command(cls=CustomClickCommand)
 @handle_cli_exceptions
 @command_with_output(
-    "crses[].{Authority:baseCRSAuthorityCode.auth,Code:baseCRSAuthorityCode.code,Type:crstype}"
+    "crses[].{Name:aliasNames[0],Authority:baseCRSAuthorityCode.auth,Code:baseCRSAuthorityCode.code,Type:crstype,Source:source}"  # noqa: E501 pylint:disable=line-too-long
 )
 def _click_command(state: State):
-    """List CRS's"""
+    """List coordinate referense systems"""
     return crs_list(state)
 
 
 def crs_list(state: State):
-    """List CRS's
+    """List coordinate referense systems
 
     Args:
         state (State): Global state
