@@ -20,8 +20,8 @@ import requests
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
-from osducli.commands.dataload.status import check_status
 from osducli.commands.dataload.verify import batch_verify
+from osducli.commands.workflow.status import check_status
 from osducli.config import (
     CONFIG_ACL_OWNER,
     CONFIG_ACL_VIEWER,
