@@ -14,14 +14,14 @@
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
 
 from ..groups.members import list_group_members
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-g", "--group", help="Email address of the group", required=True)
 @handle_cli_exceptions
 @command_with_output("members[*]")
