@@ -17,6 +17,7 @@ import click
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
 from osducli.commands.legal._const import (
+    LEGAL_DOCUMENTATION,
     LEGAL_SERVICE_NAME,
     LEGAL_STATUS_PATH,
     LEGAL_SWAGGER_PATH,
@@ -31,4 +32,11 @@ from osducli.util.service_info import info
 @command_with_output(None)
 def _click_command(state: State) -> dict:
     """Information about the service"""
-    return info(state, LEGAL_SERVICE_NAME, CONFIG_LEGAL_URL, LEGAL_STATUS_PATH, LEGAL_SWAGGER_PATH)
+    return info(
+        state,
+        LEGAL_SERVICE_NAME,
+        CONFIG_LEGAL_URL,
+        LEGAL_STATUS_PATH,
+        LEGAL_SWAGGER_PATH,
+        LEGAL_DOCUMENTATION,
+    )
